==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/db1/structIndustry.js <==
var structIndustry =
[
    [ "Industry", "d4/db1/structIndustry.html#ad7056a0119722982072b55cbc6c96108", null ],
    [ "~Industry", "d4/db1/structIndustry.html#ac0b5a2811e211cc0a5fb3f608b3c6bbb", null ],
    [ "DecIndustryTypeCount", "d4/db1/structIndustry.html#ae65e173ea717bb6e367114de297dff29", null ],
    [ "GetByTile", "d4/db1/structIndustry.html#a49b8885a24479a7a90f89402b336cad3", null ],
    [ "GetCargoAcceptedIndex", "d4/db1/structIndustry.html#a6cd3eba6cbfce556f433533b2934c5f7", null ],
    [ "GetCargoProducedIndex", "d4/db1/structIndustry.html#a14a807f4bf136e972ba1a5bbbe46c6a7", null ],
    [ "GetIndustryTypeCount", "d4/db1/structIndustry.html#a5af0b1f97315d5a76acad6cca686b504", null ],
    [ "GetRandom", "d4/db1/structIndustry.html#a031c131e42476ca9668f22e1796948ae", null ],
    [ "IncIndustryTypeCount", "d4/db1/structIndustry.html#ab318b6a910f3448c35d45b1bcf3d82de", null ],
    [ "PostDestructor", "d4/db1/structIndustry.html#a55be81ae77a37643ab802d01e49f5809", null ],
    [ "RecomputeProductionMultipliers", "d4/db1/structIndustry.html#a222302e72e5012631b528586773f88e2", null ],
    [ "ResetIndustryCounts", "d4/db1/structIndustry.html#a8a5acc7c795d180be882165275409086", null ],
    [ "TileBelongsToIndustry", "d4/db1/structIndustry.html#ae76c87516bd9aedcfe43497a7a388ee8", null ],
    [ "accepts_cargo", "d4/db1/structIndustry.html#a224ba0c4c874dd394cf3c509d2caca79", null ],
    [ "construction_date", "d4/db1/structIndustry.html#ac46beb1eb321f9de557e4b62c0e274db", null ],
    [ "construction_type", "d4/db1/structIndustry.html#ac7f16635d8cf7a948f3fe94837a85bfb", null ],
    [ "counter", "d4/db1/structIndustry.html#a64090f6adb45ac2ecf223d2b44c93d88", null ],
    [ "counts", "d4/db1/structIndustry.html#a2c1ba25487829d754334d9d3fd80cb56", null ],
    [ "founder", "d4/db1/structIndustry.html#a9e54e5a51f7fca2b065600ada8c41a0d", null ],
    [ "incoming_cargo_waiting", "d4/db1/structIndustry.html#a0d2f42845436291e909b75856bca7a20", null ],
    [ "last_cargo_accepted_at", "d4/db1/structIndustry.html#a6020c4eb006ead1eaf1adb03e707e04e", null ],
    [ "last_month_pct_transported", "d4/db1/structIndustry.html#a324c07dbd9bb8765c83be92bbcc835f5", null ],
    [ "last_month_production", "d4/db1/structIndustry.html#aca70eedae96ace8ed526e55bf2e5edf1", null ],
    [ "last_month_transported", "d4/db1/structIndustry.html#a89b5c675bae11ade06c20f0d99c7d7e4", null ],
    [ "last_prod_year", "d4/db1/structIndustry.html#a7ee8b731123cfde4dd0e53a4d25ad728", null ],
    [ "location", "d4/db1/structIndustry.html#abb85626a151ff53d5e54b717f764d7a7", null ],
    [ "owner", "d4/db1/structIndustry.html#aa92176363593ea28fddfbc8bbe8c7453", null ],
    [ "part_of_subsidy", "d4/db1/structIndustry.html#a350432f7837188766f0fc1049ff25345", null ],
    [ "prod_level", "d4/db1/structIndustry.html#a6e38ef04c9aca8ced5b46c661ea0105b", null ],
    [ "produced_cargo", "d4/db1/structIndustry.html#a292f638ccd943faeb7499230c687ff97", null ],
    [ "produced_cargo_waiting", "d4/db1/structIndustry.html#a23f620c5cfc17acc8d5c0fabf9d8e77f", null ],
    [ "production_rate", "d4/db1/structIndustry.html#abcf5aa3a36512064154646d3fd0936db", null ],
    [ "psa", "d4/db1/structIndustry.html#a1f3efa7cf49a33d9c089498e26191ddb", null ],
    [ "random", "d4/db1/structIndustry.html#ac35ea0b1f016a4c1578013d67ab79cca", null ],
    [ "random_colour", "d4/db1/structIndustry.html#abf25e7957cc83463c2426328c662b2de", null ],
    [ "selected_layout", "d4/db1/structIndustry.html#a3fa907a31abd7a3856da74fcd2a348f9", null ],
    [ "this_month_production", "d4/db1/structIndustry.html#a23d261fd1d41c4f113a3e894e4f0824b", null ],
    [ "this_month_transported", "d4/db1/structIndustry.html#a79f8e1c28816168377578f1a5d825eab", null ],
    [ "town", "d4/db1/structIndustry.html#a5a0559ab7aa84dd9d8e30d959500c47b", null ],
    [ "type", "d4/db1/structIndustry.html#a064677b500e077673ffdcdf006f13a84", null ],
    [ "was_cargo_delivered", "d4/db1/structIndustry.html#a6b09aa43e5b3e85b204ee65facf01451", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/db1/structIndustry.js <==
var structIndustry =
[
    [ "Industry", "d4/db1/structIndustry.html#ad7056a0119722982072b55cbc6c96108", null ],
    [ "~Industry", "d4/db1/structIndustry.html#ac0b5a2811e211cc0a5fb3f608b3c6bbb", null ],
    [ "DecIndustryTypeCount", "d4/db1/structIndustry.html#ae65e173ea717bb6e367114de297dff29", null ],
    [ "FillCachedName", "d4/db1/structIndustry.html#ace13f59a4c8482fa1cdba409fca538ff", null ],
    [ "GetByTile", "d4/db1/structIndustry.html#a49b8885a24479a7a90f89402b336cad3", null ],
    [ "GetCachedName", "d4/db1/structIndustry.html#a99c846712d54ee6831bf712dc68f11c6", null ],
    [ "GetCargoAcceptedIndex", "d4/db1/structIndustry.html#a6cd3eba6cbfce556f433533b2934c5f7", null ],
    [ "GetCargoProducedIndex", "d4/db1/structIndustry.html#a14a807f4bf136e972ba1a5bbbe46c6a7", null ],
    [ "GetIndustryTypeCount", "d4/db1/structIndustry.html#a5af0b1f97315d5a76acad6cca686b504", null ],
    [ "GetRandom", "d4/db1/structIndustry.html#a031c131e42476ca9668f22e1796948ae", null ],
    [ "IncIndustryTypeCount", "d4/db1/structIndustry.html#ab318b6a910f3448c35d45b1bcf3d82de", null ],
    [ "PostDestructor", "d4/db1/structIndustry.html#a55be81ae77a37643ab802d01e49f5809", null ],
    [ "RecomputeProductionMultipliers", "d4/db1/structIndustry.html#a222302e72e5012631b528586773f88e2", null ],
    [ "ResetIndustryCounts", "d4/db1/structIndustry.html#a8a5acc7c795d180be882165275409086", null ],
    [ "TileBelongsToIndustry", "d4/db1/structIndustry.html#ae76c87516bd9aedcfe43497a7a388ee8", null ],
    [ "accepts_cargo", "d4/db1/structIndustry.html#a224ba0c4c874dd394cf3c509d2caca79", null ],
    [ "cached_name", "d4/db1/structIndustry.html#a3aa9a7b15eaae0b21dca8d5bd0e4863a", null ],
    [ "construction_date", "d4/db1/structIndustry.html#ac46beb1eb321f9de557e4b62c0e274db", null ],
    [ "construction_type", "d4/db1/structIndustry.html#ac7f16635d8cf7a948f3fe94837a85bfb", null ],
    [ "counter", "d4/db1/structIndustry.html#a64090f6adb45ac2ecf223d2b44c93d88", null ],
    [ "counts", "d4/db1/structIndustry.html#a2c1ba25487829d754334d9d3fd80cb56", null ],
    [ "ctlflags", "d4/db1/structIndustry.html#a1574eac497930a8c33e546fb6dcbe016", null ],
    [ "exclusive_consumer", "d4/db1/structIndustry.html#ad5fbf38eee8c77717cbce701efa60599", null ],
    [ "exclusive_supplier", "d4/db1/structIndustry.html#a091107eaf67bd505747856bf279a8743", null ],
    [ "founder", "d4/db1/structIndustry.html#a68570351a2d3dbdcfe3b770a656dfd85", null ],
    [ "incoming_cargo_waiting", "d4/db1/structIndustry.html#a0d2f42845436291e909b75856bca7a20", null ],
    [ "last_cargo_accepted_at", "d4/db1/structIndustry.html#a6020c4eb006ead1eaf1adb03e707e04e", null ],
    [ "last_month_pct_transported", "d4/db1/structIndustry.html#a324c07dbd9bb8765c83be92bbcc835f5", null ],
    [ "last_month_production", "d4/db1/structIndustry.html#aca70eedae96ace8ed526e55bf2e5edf1", null ],
    [ "last_month_transported", "d4/db1/structIndustry.html#a89b5c675bae11ade06c20f0d99c7d7e4", null ],
    [ "last_prod_year", "d4/db1/structIndustry.html#a7ee8b731123cfde4dd0e53a4d25ad728", null ],
    [ "location", "d4/db1/structIndustry.html#abb85626a151ff53d5e54b717f764d7a7", null ],
    [ "neutral_station", "d4/db1/structIndustry.html#abe7061e9fd162c23c27d8c9f8ef7a646", null ],
    [ "owner", "d4/db1/structIndustry.html#aa26002261dace5a5955ea79f5363b901", null ],
    [ "part_of_subsidy", "d4/db1/structIndustry.html#afdbf5f7aac2f88a8e9d40a98f4d06cdb", null ],
    [ "prod_level", "d4/db1/structIndustry.html#a6e38ef04c9aca8ced5b46c661ea0105b", null ],
    [ "produced_cargo", "d4/db1/structIndustry.html#a292f638ccd943faeb7499230c687ff97", null ],
    [ "produced_cargo_waiting", "d4/db1/structIndustry.html#a23f620c5cfc17acc8d5c0fabf9d8e77f", null ],
    [ "production_rate", "d4/db1/structIndustry.html#abcf5aa3a36512064154646d3fd0936db", null ],
    [ "psa", "d4/db1/structIndustry.html#a1f3efa7cf49a33d9c089498e26191ddb", null ],
    [ "random", "d4/db1/structIndustry.html#ac35ea0b1f016a4c1578013d67ab79cca", null ],
    [ "random_colour", "d4/db1/structIndustry.html#abf25e7957cc83463c2426328c662b2de", null ],
    [ "selected_layout", "d4/db1/structIndustry.html#a3fa907a31abd7a3856da74fcd2a348f9", null ],
    [ "stations_near", "d4/db1/structIndustry.html#ad36c4861b747a3f211fff0e2ead1eac8", null ],
    [ "text", "d4/db1/structIndustry.html#a87ca98b0f8150f1ff545f928514aff58", null ],
    [ "this_month_production", "d4/db1/structIndustry.html#a23d261fd1d41c4f113a3e894e4f0824b", null ],
    [ "this_month_transported", "d4/db1/structIndustry.html#a79f8e1c28816168377578f1a5d825eab", null ],
    [ "town", "d4/db1/structIndustry.html#a5a0559ab7aa84dd9d8e30d959500c47b", null ],
    [ "type", "d4/db1/structIndustry.html#a064677b500e077673ffdcdf006f13a84", null ],
    [ "was_cargo_delivered", "d4/db1/structIndustry.html#a6b09aa43e5b3e85b204ee65facf01451", null ]
];
